import axios from 'axios'
import store from '@/store'
import { getToken } from './util'
// import { Spin } from 'iview'
const addErrorLog = errorInfo => {
  const { statusText, status, request: { responseURL } } = errorInfo
  let info = {
    type: 'ajax',
    code: status,
    mes: statusText,
    url: responseURL
  }
  if (!responseURL.includes('save_error_logger')) store.dispatch('addErrorLog', info)
}

class HttpRequest {
  constructor (baseUrl = baseURL,confapp) {
    this.baseUrl = baseUrl
    this.queue = {}
    this.confapp=confapp
  }
  getInsideConfig () {
    let appkey=null
    let companykey=null
    let regrole=null
    try{
        let params = new URLSearchParams(location.search)
        appkey=params.get("appkey")
        companykey=params.get("companykey")
        regrole=params.get("regrole")
        this.confapp.regrole=regrole
        this.confapp.fromcompanykey=companykey?companykey:this.confapp.companykey//来源公司key,如果URL里没有，那么就取平台应用公司
        this.confapp.fromappkey=appkey?appkey:this.confapp.appkey;//来源应用，如果URL里没有，那么就取平台应用key
    }catch(e){
       console.log(e)
    }
    const config = {
      baseURL: this.baseUrl,
      headers: {
        Authorization:"Bearer "+getToken(),
        XAPPKEY:this.confapp.appkey,//当前应用
        XFROMAPPKEY: this.confapp.fromappkey,//来源应用
        XFROMCOMPANYKEY: this.confapp.fromcompanykey,//来源公司
        XREGROLE:regrole,//专用于注册时，区分是否是非租户注册
        XBIZPATH:this.confapp.bizpath
      }
    }
    return config
  }
  destroy (url) {
    delete this.queue[url]
    if (!Object.keys(this.queue).length) {
      // Spin.hide()
    }
  }
  interceptors (instance, url) {
    // 请求拦截
    instance.interceptors.request.use(config => {
      // 添加全局的loading...
      if (!Object.keys(this.queue).length) {
        // Spin.show() // 不建议开启，因为界面不友好
      }
      this.queue[url] = true
      return config
    }, error => {
      console.log(error)
      return Promise.reject(error)
    })
    // 响应拦截
    instance.interceptors.response.use(res => {
      this.destroy(url)
      const { data, status } = res
      return { data, status }
    }, error => {
      this.destroy(url)
      let errorInfo = error.response
      if (!errorInfo) {
        const { request: { statusText, status }, config } = JSON.parse(JSON.stringify(error))
        errorInfo = {
          statusText,
          status,
          request: { responseURL: config.url }
        }
      }
      addErrorLog(errorInfo)
      return Promise.reject(error)
    })
  }
  request (options) {
    const instance = axios.create()
    options = Object.assign(this.getInsideConfig(), options)
    this.interceptors(instance, options.url)
    return instance(options)
  }
}
export default HttpRequest
